@@ -9,15 +9,15 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.0.22"
+#define MYSQL_SERVER_VERSION		"5.0.24a"
 #define MYSQL_BASE_VERSION		"mysqld-5.0"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50022
+#define MYSQL_VERSION_ID		50024
 #define MYSQL_PORT			3306
 #define MYSQL_UNIX_ADDR			"/var/run/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mysql-server-5.0.22"
+#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mysql-server-5.0.24a"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
